Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/mii 802.2 22.2.4.1.1 "Reset" says The reset shall be...



details:   https://anonhg.NetBSD.org/src/rev/3a5b7b297742
branches:  trunk
changeset: 447010:3a5b7b297742
user:      msaitoh <msaitoh%NetBSD.org@localhost>
date:      Fri Dec 28 05:56:07 2018 +0000

description:
802.2 22.2.4.1.1 "Reset" says The reset shall be completed in 0.5s, so change
the value from 100ms to 500ms.

diffstat:

 sys/dev/mii/mii_physubr.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (29 lines):

diff -r 84436b401223 -r 3a5b7b297742 sys/dev/mii/mii_physubr.c
--- a/sys/dev/mii/mii_physubr.c Fri Dec 28 05:04:55 2018 +0000
+++ b/sys/dev/mii/mii_physubr.c Fri Dec 28 05:56:07 2018 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mii_physubr.c,v 1.81 2018/03/05 08:56:49 msaitoh Exp $ */
+/*     $NetBSD: mii_physubr.c,v 1.82 2018/12/28 05:56:07 msaitoh Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mii_physubr.c,v 1.81 2018/03/05 08:56:49 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mii_physubr.c,v 1.82 2018/12/28 05:56:07 msaitoh Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -387,8 +387,8 @@
                reg = BMCR_RESET | BMCR_ISO;
        PHY_WRITE(sc, MII_BMCR, reg);
 
-       /* Wait another 100ms for it to complete. */
-       for (i = 0; i < 100; i++) {
+       /* Wait another 500ms for it to complete. */
+       for (i = 0; i < 500; i++) {
                reg = PHY_READ(sc, MII_BMCR);
                if ((reg & BMCR_RESET) == 0)
                        break;



Home | Main Index | Thread Index | Old Index